# Cashier Server Python

## Running Python

- Use `uv` to run Python code

## Running Tests

- The tests are in `/tests` directory.
- Use `uv run pytest` to run tests.

## Tools

- use ripgrep (`rg`) for fast text search across files
